@@ -9,7 +9,8 @@ a pipe to a file an image is written. The default image format is PNG.
 import optparse
 import os
 import sys
-from typing import Dict, Iterable, NoReturn, Optional, Set, Type
+from typing import NoReturn, Optional
+from collections.abc import Iterable
 from importlib import metadata
 
 import qrcode
@@ -140,7 +141,7 @@ def main(args=None):
         img.save(sys.stdout.buffer)
 
 
-def get_factory(module: str) -> Type[BaseImage]:
+def get_factory(module: str) -> type[BaseImage]:
     if "." not in module:
         raise ValueError("The image factory is not a full python path")
     module, name = module.rsplit(".", 1)
@@ -149,7 +150,7 @@ def get_factory(module: str) -> Type[BaseImage]:
 
 
 def get_drawer_help() -> str:
-    help: Dict[str, Set] = {}
+    help: dict[str, set] = {}
     for alias, module in default_factories.items():
         try:
             image = get_factory(module)
